@@ -7,7 +7,7 @@ expectedColumnCount <- 5
 actualColumnCount <- ncol(Links79Pair)
 stopifnot(all.equal(expectedColumnCount, actualColumnCount))
 
-expectedRowCount <- 11075
+expectedRowCount <- 42773 #42714 #11075
 actualRowCount <- nrow(Links79Pair)
 stopifnot(all.equal(expectedRowCount, actualRowCount))
 
@@ -16,10 +16,10 @@ rm(list=ls(all=TRUE))
 require(NlsyLinks)
 data(Links79PairExpanded)
 
-expectedColumnCount <- 25
+expectedColumnCount <- 26
 actualColumnCount <- ncol(Links79PairExpanded)
 stopifnot(all.equal(expectedColumnCount, actualColumnCount))
 
-expectedRowCount <- 11075
+expectedRowCount <- 42773 #42714 #11075
 actualRowCount <- nrow(Links79PairExpanded)
 stopifnot(all.equal(expectedRowCount, actualRowCount))
